define(
//begin v1.x content
({
	insertTableTitle: "Wstawianie tabeli",
	modifyTableTitle: "Modyfikowanie tabeli",
	rows: "Wiersze:",
	columns: "Kolumny:",
	align: "Wyrównanie:",
	cellPadding: "Dopełnianie komórek:",
	cellSpacing: "Odstępy między komórkami:",
	tableWidth: "Szerokość tabeli:",
	backgroundColor: "Kolor tła:",
	borderColor: "Kolor ramki:",
	borderThickness: "Grubość ramki",
	percent: "procent",
	pixels: "piksle",
	"default": "domyślna",
	left: "lewa strona",
	center: "środek",
	right: "prawa strona",
	buttonSet: "Ustaw", // translated elsewhere?
	buttonInsert: "Wstaw",
	buttonCancel: "Anuluj",

	selectTableLabel: "Wybierz tabelę",
	insertTableRowBeforeLabel: "Dodaj wiersz przed",
	insertTableRowAfterLabel: "Dodaj wiersz po",
	insertTableColumnBeforeLabel: "Dodaj kolumnę przed",
	insertTableColumnAfterLabel: "Dodaj kolumnę po",
	deleteTableRowLabel: "Usuń wiersz",
	deleteTableColumnLabel: "Usuń kolumnę"
})
//end v1.x content
);
